#!/usr/bin/python3 -Es
# -*- coding: utf-8 -*-
#
# Copyright (C) 2002-2018 Red Hat, Inc.
#
# Authors:
# Than Ngo <than@redhat.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import sys
import signal
import os
import gettext
from backend import *

import gi
gi.require_version('Gtk', '3.0')
from gi.repository import Gtk

#
# I18N
#
gettext.textdomain(PROGNAME)
_ = gettext.gettext

class mainDialog:
    def __init__(self):
        self.builder = Gtk.Builder()
        self.builder.set_translation_domain(PROGNAME)
        self.builder.add_from_file(GLADEFILE)

        self.handlers = {
            "infoDialog_closed" : (self.onDeleteDialog, INFODIALOG),
            "warnDialog_closed" : (self.onDeleteDialog, WARNDIALOG),
            "infoDialog_ok_clicked" : (self.onDeleteDialog, INFODIALOG),            
            "warnDialog_ok_clicked" : (self.onDeleteDialog, WARNDIALOG),         
            "onDeleteWindow" : self.onDeleteWindow,
            "on_sendmailRB_toggled" : self.changed,
            "on_postfixRB_toggled" : self.changed,
            "on_eximRB_toggled" : self.changed,
            "on_ssmtpRB_toggled" : self.changed,
            "on_esmtpRB_toggled" : self.changed,
            "on_cancelB_clicked" : self.on_cancelB_clicked,
            "on_okB_clicked" : self.on_okB_clicked,
        }
        
        self.builder.connect_signals(self.handlers)
        self.window = self.builder.get_object("window")
        self.okB = self.builder.get_object("okB")
        self.localCB = self.builder.get_object("localCB")
        self.infoDialog = self.builder.get_object("infoDialog")
        self.infoDialog.set_transient_for(self.window)
        self.warnDialog = self.builder.get_object("warnDialog")
        self.warnDialog.set_transient_for(self.window)
        self.sendmail_widget = self.builder.get_object('sendmailRB')
        self.postfix_widget = self.builder.get_object('postfixRB')
        self.exim_widget = self.builder.get_object('eximRB')
        self.ssmtp_widget = self.builder.get_object('ssmtpRB')
        self.esmtp_widget = self.builder.get_object('esmtpRB')
        self.window.show()
        self.hydrate()
        self.okB.set_sensitive(False)
        Gtk.main()
        
    def changed(self, *args):
        self.okB.set_sensitive(True)

    def onDeleteWindow(self, *args):
        Gtk.main_quit()
        
    def onDeleteDialog(self, button, w):
        if w == INFODIALOG:
            self.infoDialog.destroy()
        else:
            self.warnDialog.destroy()

    def on_cancelB_clicked(self, button):
        Gtk.main_quit()

    def on_okB_clicked(self, button):
        self.window.hide()
        if self.sendmail_widget.get_active():
            switch(SENDMAIL)
        elif self.postfix_widget.get_active():
            switch(POSTFIX)
        elif self.exim_widget.get_active():
            switch(EXIM)
        elif self.ssmtp_widget.get_active():
            switch(SSMTP)
        elif self.esmtp_widget.get_active():
            switch(ESMTP)

        self.showInfoDialog()
        Gtk.main_quit()

    def hydrate(self):
        mta_list = get_mta()

        if len(mta_list) == 0:
            self.showWarningDialog()
            sys.exit(1)

        # show mta checkbox
        for mta in mta_list:
            if mta == 'Sendmail':
                self.sendmail_widget.show()
            if mta == 'Postfix':
                self.postfix_widget.show()
            if mta == 'Exim':
                self.exim_widget.show()
            if mta == 'sSMTP':
                self.ssmtp_widget.show()
            if mta == 'ESMTP':
                self.esmtp_widget.show()

        # activate default mta
        mta = get_default_mta(mta_list)
        if mta == 'Sendmail':
            self.sendmail_widget.set_active(True)
        elif mta == 'Postfix':
                self.postfix_widget.set_active(True)
        elif mta == 'Exim':
            self.exim_widget.set_active(True)
        elif mta == 'sSMTP':
            self.ssmtp_widget.set_active(True)
        elif mta == 'ESMTP':
            self.esmtp_widget.set_active(True)

    def showInfoDialog(self):
        self.infoDialog.run()
        self.infoDialog.destroy()

    def showWarningDialog(self):
        self.warnDialog.run()
        self.warnDialog.destroy()
        Gtk.main_quit()


# MAIN
signal.signal (signal.SIGINT, signal.SIG_DFL)
app = mainDialog()
sys.exit(0)
